@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2013 Peter Hatina <phatina@redhat.com>
+# Copyright (C) 2012-2014 Peter Hatina <phatina@redhat.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,40 +16,24 @@
 # Base class for classes, that are used for tab-completion.
 # Used due to deprecated methods since python 2.2.
 
-class LMIBaseObject(object):
+class LMIWrapperBaseObject(object):
     """
-    Base class for all LMI classes. It is useful for rlcompleter
-    module.
-    """
-    # deprecated
-    def __methods__(self):
-        return []
+    Base class for all LMI wrapper classes, such as :py:class:`LMINamespace`,
+    :py:class:`LMIClass`, :py:class:`LMIInstanceName`, :py:class:`LMIInstance`,
+    :py:class:`LMIMethod`.
 
-    # deprecated
-    def __members__(self):
-        return []
-
-    def __call__(self):
-        pass
-
-class LMIWrapperBaseObject(LMIBaseObject):
-    """
-    Base class for all LMI wrapper classes, such as LMINamespace, LMIClass,
-    LMIInstanceName, LMIInstance, LMIMethod.
+    :param LMIConnection conn: connection object
     """
     def __init__(self, conn):
-        """
-        Constructs LMIWrapperBaseObject instance.
-
-        Arguments:
-            conn -- LMIConnection object
-        """
         super(LMIWrapperBaseObject, self).__init__()
         self._conn = conn
 
     @property
     def connection(self):
         """
-        Property returning LMIConnection object.
+        Property returning :class:`LMIConnection` object.
+
+        :returns: connection object
+        :rtype: :py:class:`LMIConnection`
         """
         return self._conn
