@@ -246,6 +246,8 @@ class LMIClass(LMIWrapperBaseObject):
 
         :param dictionary inst_filter: filter values, where the key corresponds to the key
             of :py:class:`CIMInstance`; value contains the filtering value
+        :param bool client_filtering: if True, client-side filtering will be performed,
+            otherwise the filtering will be done by a CIMOM. Default value is False.
         :param dictionary kwargs: deprecated keyword arguments
 
             * **Key** or **key** (*string*) -- filtering key, see above
@@ -271,6 +273,8 @@ class LMIClass(LMIWrapperBaseObject):
 
         :param dictionary inst_filter: filter values, where the key corresponds to the key
             of :py:class:`CIMInstance`; value contains the filtering value.
+        :param bool client_filtering: if True, client-side filtering will be performed,
+            otherwise the filtering will be done by a CIMOM. Default value is False.
         :param dictionary kwargs: deprecated keyword arguments
 
             * **Key** or **key** -- filtering key, see above
@@ -343,7 +347,8 @@ class LMIClass(LMIWrapperBaseObject):
         **Usage:** See :ref:`class_methods`.
         **Note:** When caching is turned off, this method may consume some time.
         """
-        (class_names, _, _) = self._conn._client._get_class_names(self.namespace)
+        (class_names, _, _) = self._conn._client._get_class_names(
+            self.namespace, DeepInheritance=True)
         methods_lst = self._cim_class.methods.keys()
         # Iterate through a list of all CIM methods and append any method which
         # can be called in the synchronous way. One type of such method is the
