@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2013 Peter Hatina <phatina@redhat.com>
+# Copyright (C) 2012-2014 Peter Hatina <phatina@redhat.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,25 +16,25 @@
 class LMIIndication(object):
     """
     Class representing a received indication.
+
+    :param tuple export_methods: tuple tree for export methods
+
+    **NOTE:** see :py:mod:`pywbem`
     """
     def __init__(self, export_methods):
-        """
-        Constructs a LMIIndication object.
-
-        Arguments:
-            export_methods -- tuple tree for export methods, see pywbem
-        """
         self._export_methods = export_methods
 
     def export_method_names(self):
         """
-        Returns the tuple tree for export methods, see pywbem.
+        :returns: tuple tree for export methods
+
+        **NOTE:** see :py:mod:`pywbem`
         """
         return self._export_methods.keys()
 
     def exported_objects(self):
         """
-        Returns a list of exported CIMInstance objects.
+        :returns: list of exported :py:class:`CIMInstance` objects
         """
         result = []
         for m in self._export_methods.values():
