@@ -98,14 +98,13 @@ class LMIInstance(LMIWrapperBaseObject):
         """
         if name in self.__dict__:
             return self.__dict__[name]
-        methods = self.methods()
-        if methods and name in methods:
-            return lmi_wrap_cim_method(self._conn, name, self)
-        elif name in self._cim_instance:
+        if name in self._cim_instance:
             member = self._cim_instance[name]
             if isinstance(member, pywbem.CIMInstanceName):
                 member = lmi_wrap_cim_instance_name(self._conn, member)
             return member
+        elif name in self.methods():
+            return lmi_wrap_cim_method(self._conn, name, self)
         raise AttributeError(name)
 
     @lmi_possibly_deleted(None)
