@@ -175,7 +175,10 @@ class LMIMethod(LMIWrapperBaseObject):
             # Store the synchronous flag and trim the method name
             self._sync_method = True
             method = method[4:]
-        self._method = lmi_instance._lmi_class._cim_class.methods[method]
+
+        # We need to have CIMClass with qualifiers. Fetch full class.
+        self._lmi_instance._lmi_class.fetch(True)
+        self._method = self._lmi_instance._lmi_class._cim_class.methods[method]
         # Store the constant values as a list. This can consume some time, if computed on demand.
         self._valuemap_parameters_list = [k for (k, v) in self._method.parameters.iteritems() \
             if "ValueMap" in v.qualifiers]
